@@ -3,10 +3,10 @@
  *  Module    : group.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2016-01-26
+ *  Updated   : 2017-10-24
  *  Notes     :
  *
- * Copyright (c) 1991-2016 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -620,7 +620,7 @@ group_page(
 					 * This loop looks for any article in the thread that
 					 * isn't already tagged.
 					 */
-					for (ii = n; ii != -1 && tagged; ii = arts[ii].thread) {
+					for (ii = n; ii != -1; ii = arts[ii].thread) {
 						if (arts[ii].tagged == 0) {
 							tagged = FALSE;
 							break;
@@ -1146,18 +1146,18 @@ build_sline(
 	int i)
 {
 	char *fmt, *buf;
+	char *buffer;
 	char arts_sub[HEADER_LEN];
 	char tmp_buf[8];
 	char tmp[LEN];
 	int respnum;
-	int n, j;
-	int k, fill, gap;
+	int j, k, n;
 	size_t len;
 	struct t_art_stat sbuf;
-	char *buffer;
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	wchar_t *wtmp, *wtmp2;
 #else
+	int fill, gap;
 	size_t len_start;
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
@@ -1350,15 +1350,10 @@ build_sline(
 	/* protect display from non-displayable characters (e.g., form-feed) */
 	convert_to_printable(buffer, FALSE);
 
-	if (!tinrc.strip_blanks) {
-		/* Pad to end of line so that inverse bar looks 'good' */
-		fill = cCOLS - strwidth(buffer);
-		gap = strlen(buffer);
-		for (k = 0; k < fill; k++)
-			buffer[gap + k] = ' ';
-
-		buffer[gap + fill] = '\0';
-	}
+#ifndef USE_CURSES
+	if (tinrc.strip_blanks)
+		strcat(strip_line(buffer), cCRLF);
+#endif /* !USE_CURSES */
 
 	WriteLine(INDEX2LNUM(i), buffer);
 
@@ -1414,9 +1409,9 @@ show_group_title(
 		*txt_threading[curr_group->attribute->thread_articles]);
 
 	/* article count */
-	if (cmdline.args & CMDLINE_GETART_LIMIT ? cmdline.getart_limit : tinrc.getart_limit)
+	if ((cmdline.args & CMDLINE_GETART_LIMIT) ? cmdline.getart_limit : tinrc.getart_limit)
 		snprintf(tmp, sizeof(tmp), " %d/%d%c",
-			cmdline.args & CMDLINE_GETART_LIMIT ? cmdline.getart_limit : tinrc.getart_limit, art_cnt,
+			(cmdline.args & CMDLINE_GETART_LIMIT) ? cmdline.getart_limit : tinrc.getart_limit, art_cnt,
 			(curr_group->attribute->show_only_unread_arts ? tinrc.art_marked_unread : tinrc.art_marked_read));
 	else
 		snprintf(tmp, sizeof(tmp), " %d%c",
@@ -1487,7 +1482,7 @@ do_search(
 	start = ((func == GLOBAL_SEARCH_SUBJECT_FORWARD || func == GLOBAL_SEARCH_AUTHOR_FORWARD)
 		&& grpmenu.curr < grpmenu.max - 1) ? prev_response((int) base[grpmenu.curr + 1]) : (int) base[grpmenu.curr];
 
-	if ((n = search(func, start, repeat)) != -1) {
+	if (start >= 0 && ((n = search(func, start, repeat)) != -1)) {
 		grpmenu.curr = which_thread(n);
 
 		/*
@@ -1671,7 +1666,7 @@ prompt_getart_limit(
 	t_bool ret = FALSE;
 
 	clear_message();
-	if ((p = tin_getline(_(txt_enter_getart_limit), 2, 0, 0, FALSE, HIST_OTHER)) != NULL) {
+	if ((p = tin_getline(_(txt_enter_getart_limit), 2, NULL, 0, FALSE, HIST_OTHER)) != NULL) {
 		tinrc.getart_limit = atoi(p);
 		ret = TRUE;
 	}
